^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Changelog for package sensor_msgs
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

4.2.4 (2024-05-21)
------------------

4.2.3 (2023-01-09)
------------------

4.2.2 (2022-05-19)
------------------

4.2.1 (2022-03-31)
------------------
* Move the find_package statements for BUILD_TESTING  (`#186 <https://github.com/ros2/common_interfaces/issues/186>`_)
* Contributors: Michael Jeronimo

4.2.0 (2022-03-30)
------------------

4.1.1 (2022-03-26)
------------------
* Feedback on conditional sensor_msgs_library target (`#1 <https://github.com/ros2/common_interfaces/issues/1>`_) (`#183 <https://github.com/ros2/common_interfaces/issues/183>`_)
* [Fix] Fix image_encodings.hpp's URL in README (`#184 <https://github.com/ros2/common_interfaces/issues/184>`_)
* [Fix] Fix fill_image.hpp's URL in README (`#182 <https://github.com/ros2/common_interfaces/issues/182>`_)
* Add sensor_msgs_library target and install headers to include/${PROJECT_NAME} (`#178 <https://github.com/ros2/common_interfaces/issues/178>`_)
* Contributors: Homalozoa X, Pablo Garrido, Shane Loretz

4.1.0 (2022-03-01)
------------------
* Interface packages should fully <depend> on the interface packages that they depend on (`#173 <https://github.com/ros2/common_interfaces/issues/173>`_)
* Add YUV420 and YUV444 to image encodings (`#172 <https://github.com/ros2/common_interfaces/issues/172>`_)
* Contributors: Grey, Hemal Shah

4.0.0 (2021-12-14)
------------------
* Cleanup mislabeled BSD license (`#83 <https://github.com/ros2/common_interfaces/issues/83>`_)
* Update maintainers to Geoffrey Biggs and Tully Foote (`#163 <https://github.com/ros2/common_interfaces/issues/163>`_)
* Fix rosdoc2 warnings in sensor_msgs. (`#162 <https://github.com/ros2/common_interfaces/issues/162>`_)
* Add equidistant distortion model (`#160 <https://github.com/ros2/common_interfaces/issues/160>`_)
* Contributors: Audrow Nash, Chris Lalancette, Martin Günther, Tully Foote

3.0.0 (2021-08-24)
------------------

2.3.0 (2021-08-11)
------------------
* Use rosidl_get_typesupport_target() (`#156 <https://github.com/ros2/common_interfaces/issues/156>`_)
* Update CompressedImage documentation: add 'tiff' as a supported format (`#154 <https://github.com/ros2/common_interfaces/issues/154>`_)
* Contributors: Ivan Santiago Paunovic, Shane Loretz

2.2.3 (2021-04-27)
------------------

2.2.2 (2021-04-06)
------------------
* Change index.ros.org -> docs.ros.org. (`#149 <https://github.com/ros2/common_interfaces/issues/149>`_)
* updating quality declaration links (re: `ros2/docs.ros2.org#52 <https://github.com/ros2/docs.ros2.org/issues/52>`_) (`#145 <https://github.com/ros2/common_interfaces/issues/145>`_)
* Contributors: Chris Lalancette, shonigmann

2.2.1 (2021-01-25)
------------------
* Fix PointCloud2Iterator namespacing in docs (`#139 <https://github.com/ros2/common_interfaces/issues/139>`_)
* Contributors: Andre Nguyen

2.2.0 (2020-12-10)
------------------
* Add coverage/performance to qd for sensor_msgs (`#137 <https://github.com/ros2/common_interfaces/issues/137>`_)
* Update QDs to QL 1 (`#135 <https://github.com/ros2/common_interfaces/issues/135>`_)
* Update package maintainers. (`#132 <https://github.com/ros2/common_interfaces/issues/132>`_)
* Updated Quality Level to 2 (`#131 <https://github.com/ros2/common_interfaces/issues/131>`_)
* Contributors: Alejandro Hernández Cordero, Michel Hidalgo, Stephen Brawner

2.1.0 (2020-07-21)
------------------

2.0.2 (2020-07-21)
------------------
* Missing cstring header for memcpy in fill_image.hpp (`#126 <https://github.com/ros2/common_interfaces/issues/126>`_)
* Update Quality levels to level 3 (`#124 <https://github.com/ros2/common_interfaces/issues/124>`_)
* Add Security Vulnerability Policy pointing to REP-2006. (`#120 <https://github.com/ros2/common_interfaces/issues/120>`_)
* Contributors: Chris Lalancette, Jose Luis Rivero, brawner

2.0.1 (2020-05-26)
------------------
* QD Update Version Stability to stable version (`#121 <https://github.com/ros2/common_interfaces/issues/121>`_)
* Contributors: Alejandro Hernández Cordero

1.0.0 (2020-05-20)
------------------
* Improve clarification of MultiDOFJointState (`#114 <https://github.com/ros2/common_interfaces/issues/114>`_)
* Comment on common PointField names (`#112 <https://github.com/ros2/common_interfaces/issues/112>`_)
* Fix sensor_msgs README (`#111 <https://github.com/ros2/common_interfaces/issues/111>`_)
* Add current-level quality declarations (`#109 <https://github.com/ros2/common_interfaces/issues/109>`_)
* Contributors: Tully Foote, brawner
